
/*  A Bison parser, made from ../../fsinfo/fsi_gram.y
    by GNU Bison version 1.28  */

#define YYBISON 1  /* Identify Bison output.  */

#define	tARCH	257
#define	tAS	258
#define	tAUTOMOUNT	259
#define	tCLUSTER	260
#define	tCONFIG	261
#define	tDUMPSET	262
#define	tEQ	263
#define	tNFSEQ	264
#define	tEXPORTFS	265
#define	tFREQ	266
#define	tFROM	267
#define	tFS	268
#define	tFSTYPE	269
#define	tHWADDR	270
#define	tINADDR	271
#define	tHOST	272
#define	tLOCALHOST	273
#define	tLOG	274
#define	tMOUNT	275
#define	tNETMASK	276
#define	tNETIF	277
#define	tVOLNAME	278
#define	tOPTS	279
#define	tOS	280
#define	tPASSNO	281
#define	tDIRECT	282
#define	tSEL	283
#define	tSTR	284

#line 45 "../../fsinfo/fsi_gram.y"

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif /* HAVE_CONFIG_H */
#include <am_defs.h>
#include <fsi_data.h>
#include <fsinfo.h>

/* AIX requires this to be the first thing in the file. */
#ifndef __GNUC__
# if HAVE_ALLOCA_H
#  include <alloca.h>
# else /* not HAVE_ALLOCA_H */
#  ifdef _AIX
#pragma alloca
#  else /* not _AIX */
#   ifndef alloca
  /* predefined by HP cc +Olibcalls */
voidp alloca();
#   endif /* not alloca */
#  endif /* not _AIX */
# endif /* not HAVE_ALLOCA_H */
#endif /* not __GNUC__ */

extern qelem *list_of_hosts, *list_of_automounts;

#line 72 "../../fsinfo/fsi_gram.y"
typedef union {
	auto_tree *a;
	disk_fs *d;
	ether_if *e;
	host *h;
	qelem *q;
	char *s;
	fsi_mount *m;
	fsmount *f;
} YYSTYPE;
#include <stdio.h>

#ifndef __cplusplus
#ifndef __STDC__
#define const
#endif
#endif



#define	YYFINAL		124
#define	YYFLAG		-32768
#define	YYNTBASE	34

#define YYTRANSLATE(x) ((unsigned)(x) <= 284 ? yytranslate[x] : 49)

static const char yytranslate[] = {     0,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
    33,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,    31,     2,    32,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     1,     3,     4,     5,     6,
     7,     8,     9,    10,    11,    12,    13,    14,    15,    16,
    17,    18,    19,    20,    21,    22,    23,    24,    25,    26,
    27,    28,    29,    30
};

#if YYDEBUG != 0
static const short yyprhs[] = {     0,
     0,     1,     4,     7,    12,    18,    20,    25,    26,    33,
    37,    42,    47,    52,    57,    58,    63,    68,    73,    77,
    80,    81,    84,    85,    88,    94,    98,    99,   104,   109,
   114,   119,   123,   128,   133,   138,   139,   145,   151,   156,
   163,   164,   171,   172,   176,   180,   184,   189,   190,   195,
   196,   199,   203,   207,   211,   215
};

static const short yyrhs[] = {    -1,
    34,    35,     0,    34,    39,     0,    18,    36,    41,    47,
     0,     1,    18,    36,    41,    47,     0,    30,     0,    31,
    37,    32,    30,     0,     0,    37,    23,    30,    31,    38,
    32,     0,    37,     7,    30,     0,    37,     3,    33,    30,
     0,    37,    26,    33,    30,     0,    37,     6,    33,    30,
     0,    37,     1,    33,    30,     0,     0,    38,    17,    33,
    30,     0,    38,    22,    33,    30,     0,    38,    16,    33,
    30,     0,     5,    40,    44,     0,     5,     1,     0,     0,
    25,    30,     0,     0,    41,    42,     0,    14,    30,    31,
    43,    32,     0,    14,     1,    32,     0,     0,    43,    15,
    33,    30,     0,    43,    25,    33,    30,     0,    43,    27,
    33,    30,     0,    43,    12,    33,    30,     0,    43,    21,
    45,     0,    43,     8,    33,    30,     0,    43,    20,    33,
    30,     0,    43,     1,    33,    30,     0,     0,    44,    30,
    40,    33,    30,     0,    44,    30,    40,    10,    30,     0,
    44,    30,     9,    30,     0,    44,    30,    40,    31,    44,
    32,     0,     0,    45,    30,    31,    46,    45,    32,     0,
     0,    46,    11,    30,     0,    46,    24,    30,     0,    46,
    29,    30,     0,    46,     1,    33,    30,     0,     0,    47,
    21,    30,    48,     0,     0,    48,    28,     0,    48,     4,
    30,     0,    48,    13,    30,     0,    48,    15,    30,     0,
    48,    25,    30,     0,    48,     1,    33,    30,     0
};

#endif

#if YYDEBUG != 0
static const short yyrline[] = { 0,
   126,   130,   134,   144,   148,   153,   157,   162,   166,   172,
   175,   178,   181,   184,   188,   192,   194,   196,   205,   214,
   218,   222,   226,   230,   248,   252,   267,   271,   274,   277,
   280,   283,   286,   289,   292,   305,   309,   319,   330,   340,
   352,   356,   369,   373,   376,   379,   382,   391,   395,   414,
   418,   421,   424,   427,   430,   433
};
#endif


#if YYDEBUG != 0 || defined (YYERROR_VERBOSE)

static const char * const yytname[] = {   "$","error","$undefined.","tARCH",
"tAS","tAUTOMOUNT","tCLUSTER","tCONFIG","tDUMPSET","tEQ","tNFSEQ","tEXPORTFS",
"tFREQ","tFROM","tFS","tFSTYPE","tHWADDR","tINADDR","tHOST","tLOCALHOST","tLOG",
"tMOUNT","tNETMASK","tNETIF","tVOLNAME","tOPTS","tOS","tPASSNO","tDIRECT","tSEL",
"tSTR","'{'","'}'","'='","list_of_hosts","host","host_attr","host_attr_list",
"ether_attr","automount","opt_auto_opts","list_of_filesystems","filesystem",
"fs_info_list","automount_tree","dir_tree","dir_tree_info","list_of_mounts",
"localinfo_list", NULL
};
#endif

static const short yyr1[] = {     0,
    34,    34,    34,    35,    35,    36,    36,    37,    37,    37,
    37,    37,    37,    37,    38,    38,    38,    38,    39,    39,
    40,    40,    41,    41,    42,    42,    43,    43,    43,    43,
    43,    43,    43,    43,    43,    44,    44,    44,    44,    44,
    45,    45,    46,    46,    46,    46,    46,    47,    47,    48,
    48,    48,    48,    48,    48,    48
};

static const short yyr2[] = {     0,
     0,     2,     2,     4,     5,     1,     4,     0,     6,     3,
     4,     4,     4,     4,     0,     4,     4,     4,     3,     2,
     0,     2,     0,     2,     5,     3,     0,     4,     4,     4,
     4,     3,     4,     4,     4,     0,     5,     5,     4,     6,
     0,     6,     0,     3,     3,     3,     4,     0,     4,     0,
     2,     3,     3,     3,     3,     4
};

static const short yydefact[] = {     1,
     0,     0,     0,     0,     2,     3,     0,    20,     0,    36,
     6,     8,    23,    23,    22,    19,     0,    48,    48,    21,
     0,     0,     0,     0,     0,     0,     0,     0,    24,     4,
     5,     0,     0,     0,     0,     0,    10,     0,     0,     7,
     0,     0,     0,    39,     0,    36,     0,    14,    11,    13,
    15,    12,    26,    27,    50,    38,     0,    37,     0,     0,
     0,    40,     0,     0,     0,     9,     0,     0,     0,     0,
     0,    41,     0,     0,    25,     0,     0,     0,     0,     0,
    51,     0,     0,     0,     0,     0,     0,     0,     0,    32,
     0,     0,     0,    52,    53,    54,    55,    18,    16,    17,
    35,    33,    31,    28,    34,     0,    29,    30,    56,    43,
     0,     0,     0,     0,     0,     0,     0,    44,    45,    46,
    42,    47,     0,     0
};

static const short yydefgoto[] = {     1,
     5,    13,    17,    59,     6,    10,    18,    29,    60,    16,
    90,   111,    30,    61
};

static const short yypact[] = {-32768,
    46,    -8,    32,   -14,-32768,-32768,   -14,-32768,   -26,-32768,
-32768,-32768,-32768,-32768,-32768,     6,     2,    28,    28,    -7,
    12,    23,    25,    29,    30,    34,    35,     0,-32768,    47,
    47,    40,    -4,    41,    42,    44,-32768,    24,    45,-32768,
    49,    51,    50,-32768,    53,-32768,    54,-32768,-32768,-32768,
-32768,-32768,-32768,-32768,-32768,-32768,   -17,-32768,    22,    -1,
    48,-32768,    52,    55,    56,-32768,    57,    58,    59,    60,
    61,-32768,    62,    63,-32768,    64,    68,    69,    70,    71,
-32768,    72,    73,    74,    75,    76,    77,    78,    79,    80,
    81,    82,    83,-32768,-32768,-32768,-32768,-32768,-32768,-32768,
-32768,-32768,-32768,-32768,-32768,    84,-32768,-32768,-32768,-32768,
    11,    85,    86,    87,    89,    -9,    90,-32768,-32768,-32768,
-32768,-32768,   114,-32768
};

static const short yypgoto[] = {-32768,
-32768,   115,-32768,-32768,-32768,    66,    65,-32768,-32768,    31,
   -33,-32768,   102,-32768
};


#define	YYLAST		122


static const short yytable[] = {    67,
    41,    32,    21,    15,    22,    45,    68,    23,    24,     7,
    69,   112,    20,    70,    62,    11,    12,     9,    71,    72,
   106,   113,   121,    73,    25,    74,    46,    26,    47,    42,
    75,   -21,     8,    27,   114,    20,   -21,    63,    64,   115,
   -41,    28,   -41,    65,    34,   123,     2,   -49,    76,   -21,
     3,    77,   -49,    66,    51,    35,     9,    36,    37,    38,
    78,   -21,    79,     4,    40,   -49,    39,    43,   -49,    44,
    48,    49,    80,    50,    52,    81,    57,   116,    19,    55,
    53,    54,    56,    58,    82,    33,     0,    83,    84,    85,
    86,    87,    88,    89,    91,    92,    93,    94,    95,    96,
    97,    98,    99,   100,   101,   102,   103,   104,   105,   106,
   107,   108,   109,   124,   110,   118,   119,   117,   120,   122,
    31,    14
};

static const short yycheck[] = {     1,
     1,     9,     1,    30,     3,    10,     8,     6,     7,    18,
    12,     1,    30,    15,    32,    30,    31,    25,    20,    21,
    30,    11,    32,    25,    23,    27,    31,    26,    33,    30,
    32,     0,     1,    32,    24,    30,     5,    16,    17,    29,
    30,    14,    32,    22,    33,     0,     1,     0,     1,    18,
     5,     4,     5,    32,    31,    33,    25,    33,    30,    30,
    13,    30,    15,    18,    30,    18,    33,    21,    21,    30,
    30,    30,    25,    30,    30,    28,    46,   111,    14,    30,
    32,    31,    30,    30,    33,    20,    -1,    33,    33,    33,
    33,    33,    33,    33,    33,    33,    33,    30,    30,    30,
    30,    30,    30,    30,    30,    30,    30,    30,    30,    30,
    30,    30,    30,     0,    31,    30,    30,    33,    30,    30,
    19,     7
};
/* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
#line 3 "/usr/share/misc/bison.simple"
/* This file comes from bison-1.28.  */

/* Skeleton output parser for bison,
   Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* This is the parser code that is written into each bison parser
  when the %semantic_parser declaration is not specified in the grammar.
  It was written by Richard Stallman by simplifying the hairy parser
  used when %semantic_parser is specified.  */

#ifndef YYSTACK_USE_ALLOCA
#ifdef alloca
#define YYSTACK_USE_ALLOCA
#else /* alloca not defined */
#ifdef __GNUC__
#define YYSTACK_USE_ALLOCA
#define alloca __builtin_alloca
#else /* not GNU C.  */
#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc) || defined (__sgi) || (defined (__sun) && defined (__i386))
#define YYSTACK_USE_ALLOCA
#include <alloca.h>
#else /* not sparc */
/* We think this test detects Watcom and Microsoft C.  */
/* This used to test MSDOS, but that is a bad idea
   since that symbol is in the user namespace.  */
#if (defined (_MSDOS) || defined (_MSDOS_)) && !defined (__TURBOC__)
#if 0 /* No need for malloc.h, which pollutes the namespace;
	 instead, just don't use alloca.  */
#include <malloc.h>
#endif
#else /* not MSDOS, or __TURBOC__ */
#if defined(_AIX)
/* I don't know what this was needed for, but it pollutes the namespace.
   So I turned it off.   rms, 2 May 1997.  */
/* #include <malloc.h>  */
 #pragma alloca
#define YYSTACK_USE_ALLOCA
#else /* not MSDOS, or __TURBOC__, or _AIX */
#if 0
#ifdef __hpux /* haible@ilog.fr says this works for HPUX 9.05 and up,
		 and on HPUX 10.  Eventually we can turn this on.  */
#define YYSTACK_USE_ALLOCA
#define alloca __builtin_alloca
#endif /* __hpux */
#endif
#endif /* not _AIX */
#endif /* not MSDOS, or __TURBOC__ */
#endif /* not sparc */
#endif /* not GNU C */
#endif /* alloca not defined */
#endif /* YYSTACK_USE_ALLOCA not defined */

#ifdef YYSTACK_USE_ALLOCA
#define YYSTACK_ALLOC alloca
#else
#define YYSTACK_ALLOC malloc
#endif

/* Note: there must be only one dollar sign in this file.
   It is replaced by the list of actions, each action
   as one case of the switch.  */

#define yyerrok		(yyerrstatus = 0)
#define yyclearin	(yychar = YYEMPTY)
#define YYEMPTY		-2
#define YYEOF		0
#define YYACCEPT	goto yyacceptlab
#define YYABORT 	goto yyabortlab
#define YYERROR		goto yyerrlab1
/* Like YYERROR except do call yyerror.
   This remains here temporarily to ease the
   transition to the new meaning of YYERROR, for GCC.
   Once GCC version 2 has supplanted version 1, this can go.  */
#define YYFAIL		goto yyerrlab
#define YYRECOVERING()  (!!yyerrstatus)
#define YYBACKUP(token, value) \
do								\
  if (yychar == YYEMPTY && yylen == 1)				\
    { yychar = (token), yylval = (value);			\
      yychar1 = YYTRANSLATE (yychar);				\
      YYPOPSTACK;						\
      goto yybackup;						\
    }								\
  else								\
    { yyerror ("syntax error: cannot back up"); YYERROR; }	\
while (0)

#define YYTERROR	1
#define YYERRCODE	256

#ifndef YYPURE
#define YYLEX		yylex()
#endif

#ifdef YYPURE
#ifdef YYLSP_NEEDED
#ifdef YYLEX_PARAM
#define YYLEX		yylex(&yylval, &yylloc, YYLEX_PARAM)
#else
#define YYLEX		yylex(&yylval, &yylloc)
#endif
#else /* not YYLSP_NEEDED */
#ifdef YYLEX_PARAM
#define YYLEX		yylex(&yylval, YYLEX_PARAM)
#else
#define YYLEX		yylex(&yylval)
#endif
#endif /* not YYLSP_NEEDED */
#endif

/* If nonreentrant, generate the variables here */

#ifndef YYPURE

int	yychar;			/*  the lookahead symbol		*/
YYSTYPE	yylval;			/*  the semantic value of the		*/
				/*  lookahead symbol			*/

#ifdef YYLSP_NEEDED
YYLTYPE yylloc;			/*  location data for the lookahead	*/
				/*  symbol				*/
#endif

int yynerrs;			/*  number of parse errors so far       */
#endif  /* not YYPURE */

#if YYDEBUG != 0
int yydebug;			/*  nonzero means print parse trace	*/
/* Since this is uninitialized, it does not stop multiple parsers
   from coexisting.  */
#endif

/*  YYINITDEPTH indicates the initial size of the parser's stacks	*/

#ifndef	YYINITDEPTH
#define YYINITDEPTH 200
#endif

/*  YYMAXDEPTH is the maximum size the stacks can grow to
    (effective only if the built-in stack extension method is used).  */

#if YYMAXDEPTH == 0
#undef YYMAXDEPTH
#endif

#ifndef YYMAXDEPTH
#define YYMAXDEPTH 10000
#endif

/* Define __yy_memcpy.  Note that the size argument
   should be passed with type unsigned int, because that is what the non-GCC
   definitions require.  With GCC, __builtin_memcpy takes an arg
   of type size_t, but it can handle unsigned int.  */

#if __GNUC__ > 1		/* GNU C and GNU C++ define this.  */
#define __yy_memcpy(TO,FROM,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
#else				/* not GNU C or C++ */
#ifndef __cplusplus

/* This is the most reliable way to avoid incompatibilities
   in available built-in functions on various systems.  */
static void
__yy_memcpy (to, from, count)
     char *to;
     char *from;
     unsigned int count;
{
  register char *f = from;
  register char *t = to;
  register int i = count;

  while (i-- > 0)
    *t++ = *f++;
}

#else /* __cplusplus */

/* This is the most reliable way to avoid incompatibilities
   in available built-in functions on various systems.  */
static void
__yy_memcpy (char *to, char *from, unsigned int count)
{
  register char *t = to;
  register char *f = from;
  register int i = count;

  while (i-- > 0)
    *t++ = *f++;
}

#endif
#endif

#line 217 "/usr/share/misc/bison.simple"

/* The user can define YYPARSE_PARAM as the name of an argument to be passed
   into yyparse.  The argument should have type void *.
   It should actually point to an object.
   Grammar actions can access the variable by casting it
   to the proper pointer type.  */

#ifdef YYPARSE_PARAM
#ifdef __cplusplus
#define YYPARSE_PARAM_ARG void *YYPARSE_PARAM
#define YYPARSE_PARAM_DECL
#else /* not __cplusplus */
#define YYPARSE_PARAM_ARG YYPARSE_PARAM
#define YYPARSE_PARAM_DECL void *YYPARSE_PARAM;
#endif /* not __cplusplus */
#else /* not YYPARSE_PARAM */
#define YYPARSE_PARAM_ARG
#define YYPARSE_PARAM_DECL
#endif /* not YYPARSE_PARAM */

/* Prevent warning if -Wstrict-prototypes.  */
#ifdef __GNUC__
#ifdef YYPARSE_PARAM
int yyparse (void *);
#else
int yyparse (void);
#endif
#endif

int
yyparse(YYPARSE_PARAM_ARG)
     YYPARSE_PARAM_DECL
{
  register int yystate;
  register int yyn;
  register short *yyssp;
  register YYSTYPE *yyvsp;
  int yyerrstatus;	/*  number of tokens to shift before error messages enabled */
  int yychar1 = 0;		/*  lookahead token as an internal (translated) token number */

  short	yyssa[YYINITDEPTH];	/*  the state stack			*/
  YYSTYPE yyvsa[YYINITDEPTH];	/*  the semantic value stack		*/

  short *yyss = yyssa;		/*  refer to the stacks thru separate pointers */
  YYSTYPE *yyvs = yyvsa;	/*  to allow yyoverflow to reallocate them elsewhere */

#ifdef YYLSP_NEEDED
  YYLTYPE yylsa[YYINITDEPTH];	/*  the location stack			*/
  YYLTYPE *yyls = yylsa;
  YYLTYPE *yylsp;

#define YYPOPSTACK   (yyvsp--, yyssp--, yylsp--)
#else
#define YYPOPSTACK   (yyvsp--, yyssp--)
#endif

  int yystacksize = YYINITDEPTH;
  int yyfree_stacks = 0;

#ifdef YYPURE
  int yychar;
  YYSTYPE yylval;
  int yynerrs;
#ifdef YYLSP_NEEDED
  YYLTYPE yylloc;
#endif
#endif

  YYSTYPE yyval;		/*  the variable used to return		*/
				/*  semantic values from the action	*/
				/*  routines				*/

  int yylen;

#if YYDEBUG != 0
  if (yydebug)
    fprintf(stderr, "Starting parse\n");
#endif

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY;		/* Cause a token to be read.  */

  /* Initialize stack pointers.
     Waste one element of value and location stack
     so that they stay on the same level as the state stack.
     The wasted elements are never initialized.  */

  yyssp = yyss - 1;
  yyvsp = yyvs;
#ifdef YYLSP_NEEDED
  yylsp = yyls;
#endif

/* Push a new state, which is found in  yystate  .  */
/* In all cases, when you get here, the value and location stacks
   have just been pushed. so pushing a state here evens the stacks.  */
yynewstate:

  *++yyssp = yystate;

  if (yyssp >= yyss + yystacksize - 1)
    {
      /* Give user a chance to reallocate the stack */
      /* Use copies of these so that the &'s don't force the real ones into memory. */
      YYSTYPE *yyvs1 = yyvs;
      short *yyss1 = yyss;
#ifdef YYLSP_NEEDED
      YYLTYPE *yyls1 = yyls;
#endif

      /* Get the current used size of the three stacks, in elements.  */
      int size = yyssp - yyss + 1;

#ifdef yyoverflow
      /* Each stack pointer address is followed by the size of
	 the data in use in that stack, in bytes.  */
#ifdef YYLSP_NEEDED
      /* This used to be a conditional around just the two extra args,
	 but that might be undefined if yyoverflow is a macro.  */
      yyoverflow("parser stack overflow",
		 &yyss1, size * sizeof (*yyssp),
		 &yyvs1, size * sizeof (*yyvsp),
		 &yyls1, size * sizeof (*yylsp),
		 &yystacksize);
#else
      yyoverflow("parser stack overflow",
		 &yyss1, size * sizeof (*yyssp),
		 &yyvs1, size * sizeof (*yyvsp),
		 &yystacksize);
#endif

      yyss = yyss1; yyvs = yyvs1;
#ifdef YYLSP_NEEDED
      yyls = yyls1;
#endif
#else /* no yyoverflow */
      /* Extend the stack our own way.  */
      if (yystacksize >= YYMAXDEPTH)
	{
	  yyerror("parser stack overflow");
	  if (yyfree_stacks)
	    {
	      free (yyss);
	      free (yyvs);
#ifdef YYLSP_NEEDED
	      free (yyls);
#endif
	    }
	  return 2;
	}
      yystacksize *= 2;
      if (yystacksize > YYMAXDEPTH)
	yystacksize = YYMAXDEPTH;
#ifndef YYSTACK_USE_ALLOCA
      yyfree_stacks = 1;
#endif
      yyss = (short *) YYSTACK_ALLOC (yystacksize * sizeof (*yyssp));
      __yy_memcpy ((char *)yyss, (char *)yyss1,
		   size * (unsigned int) sizeof (*yyssp));
      yyvs = (YYSTYPE *) YYSTACK_ALLOC (yystacksize * sizeof (*yyvsp));
      __yy_memcpy ((char *)yyvs, (char *)yyvs1,
		   size * (unsigned int) sizeof (*yyvsp));
#ifdef YYLSP_NEEDED
      yyls = (YYLTYPE *) YYSTACK_ALLOC (yystacksize * sizeof (*yylsp));
      __yy_memcpy ((char *)yyls, (char *)yyls1,
		   size * (unsigned int) sizeof (*yylsp));
#endif
#endif /* no yyoverflow */

      yyssp = yyss + size - 1;
      yyvsp = yyvs + size - 1;
#ifdef YYLSP_NEEDED
      yylsp = yyls + size - 1;
#endif

#if YYDEBUG != 0
      if (yydebug)
	fprintf(stderr, "Stack size increased to %d\n", yystacksize);
#endif

      if (yyssp >= yyss + yystacksize - 1)
	YYABORT;
    }

#if YYDEBUG != 0
  if (yydebug)
    fprintf(stderr, "Entering state %d\n", yystate);
#endif

  goto yybackup;
 yybackup:

/* Do appropriate processing given the current state.  */
/* Read a lookahead token if we need one and don't already have one.  */
/* yyresume: */

  /* First try to decide what to do without reference to lookahead token.  */

  yyn = yypact[yystate];
  if (yyn == YYFLAG)
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* yychar is either YYEMPTY or YYEOF
     or a valid token in external form.  */

  if (yychar == YYEMPTY)
    {
#if YYDEBUG != 0
      if (yydebug)
	fprintf(stderr, "Reading a token: ");
#endif
      yychar = YYLEX;
    }

  /* Convert token to internal form (in yychar1) for indexing tables with */

  if (yychar <= 0)		/* This means end of input. */
    {
      yychar1 = 0;
      yychar = YYEOF;		/* Don't call YYLEX any more */

#if YYDEBUG != 0
      if (yydebug)
	fprintf(stderr, "Now at end of input.\n");
#endif
    }
  else
    {
      yychar1 = YYTRANSLATE(yychar);

#if YYDEBUG != 0
      if (yydebug)
	{
	  fprintf (stderr, "Next token is %d (%s", yychar, yytname[yychar1]);
	  /* Give the individual parser a way to print the precise meaning
	     of a token, for further debugging info.  */
#ifdef YYPRINT
	  YYPRINT (stderr, yychar, yylval);
#endif
	  fprintf (stderr, ")\n");
	}
#endif
    }

  yyn += yychar1;
  if (yyn < 0 || yyn > YYLAST || yycheck[yyn] != yychar1)
    goto yydefault;

  yyn = yytable[yyn];

  /* yyn is what to do for this token type in this state.
     Negative => reduce, -yyn is rule number.
     Positive => shift, yyn is new state.
       New state is final state => don't bother to shift,
       just return success.
     0, or most negative number => error.  */

  if (yyn < 0)
    {
      if (yyn == YYFLAG)
	goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }
  else if (yyn == 0)
    goto yyerrlab;

  if (yyn == YYFINAL)
    YYACCEPT;

  /* Shift the lookahead token.  */

#if YYDEBUG != 0
  if (yydebug)
    fprintf(stderr, "Shifting token %d (%s), ", yychar, yytname[yychar1]);
#endif

  /* Discard the token being shifted unless it is eof.  */
  if (yychar != YYEOF)
    yychar = YYEMPTY;

  *++yyvsp = yylval;
#ifdef YYLSP_NEEDED
  *++yylsp = yylloc;
#endif

  /* count tokens shifted since error; after three, turn off error status.  */
  if (yyerrstatus) yyerrstatus--;

  yystate = yyn;
  goto yynewstate;

/* Do the default action for the current state.  */
yydefault:

  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;

/* Do a reduction.  yyn is the number of a rule to reduce with.  */
yyreduce:
  yylen = yyr2[yyn];
  if (yylen > 0)
    yyval = yyvsp[1-yylen]; /* implement default value of the action */

#if YYDEBUG != 0
  if (yydebug)
    {
      int i;

      fprintf (stderr, "Reducing via rule %d (line %d), ",
	       yyn, yyrline[yyn]);

      /* Print the symbols being reduced, and their result.  */
      for (i = yyprhs[yyn]; yyrhs[i] > 0; i++)
	fprintf (stderr, "%s ", yytname[yyrhs[i]]);
      fprintf (stderr, " -> %s\n", yytname[yyr1[yyn]]);
    }
#endif


  switch (yyn) {

case 1:
#line 128 "../../fsinfo/fsi_gram.y"
{ yyval.q = new_que(); ;
    break;}
case 2:
#line 131 "../../fsinfo/fsi_gram.y"
{ if (yyvsp[0].h) ins_que((qelem *) yyvsp[0].h, list_of_hosts->q_back);
	    yyval.q = yyvsp[-1].q; ;
    break;}
case 3:
#line 135 "../../fsinfo/fsi_gram.y"
{ if (yyvsp[0].a) ins_que((qelem *) yyvsp[0].a, list_of_automounts->q_back);
	    yyval.q = yyvsp[-1].q; ;
    break;}
case 4:
#line 146 "../../fsinfo/fsi_gram.y"
{ yyval.h = yyvsp[-2].h; yyval.h->h_disk_fs = yyvsp[-1].q; yyval.h->h_mount = yyvsp[0].q; ;
    break;}
case 5:
#line 149 "../../fsinfo/fsi_gram.y"
{ yyval.h = yyvsp[-2].h; yyval.h->h_disk_fs = yyvsp[-1].q; yyval.h->h_mount = yyvsp[0].q; ;
    break;}
case 6:
#line 155 "../../fsinfo/fsi_gram.y"
{ yyval.h = new_host(); set_host(yyval.h, HF_HOST, yyvsp[0].s); ;
    break;}
case 7:
#line 158 "../../fsinfo/fsi_gram.y"
{ yyval.h = yyvsp[-2].h; set_host(yyval.h, HF_HOST, yyvsp[0].s); ;
    break;}
case 8:
#line 164 "../../fsinfo/fsi_gram.y"
{ yyval.h = new_host(); ;
    break;}
case 9:
#line 167 "../../fsinfo/fsi_gram.y"
{ if (yyvsp[-1].e) {
		yyvsp[-1].e->e_if = yyvsp[-3].s;
		yyval.h = yyvsp[-5].h; set_host(yyval.h, HF_ETHER, (char *) yyvsp[-1].e); }
	  ;
    break;}
case 10:
#line 173 "../../fsinfo/fsi_gram.y"
{ yyval.h = yyvsp[-2].h; set_host(yyval.h, HF_CONFIG, yyvsp[0].s); ;
    break;}
case 11:
#line 176 "../../fsinfo/fsi_gram.y"
{ yyval.h = yyvsp[-3].h; set_host(yyval.h, HF_ARCH, yyvsp[0].s); ;
    break;}
case 12:
#line 179 "../../fsinfo/fsi_gram.y"
{ yyval.h = yyvsp[-3].h; set_host(yyval.h, HF_OS, yyvsp[0].s); ;
    break;}
case 13:
#line 182 "../../fsinfo/fsi_gram.y"
{ yyval.h = yyvsp[-3].h; set_host(yyval.h, HF_CLUSTER, yyvsp[0].s); ;
    break;}
case 14:
#line 185 "../../fsinfo/fsi_gram.y"
{ yyerror("unknown host attribute"); ;
    break;}
case 15:
#line 190 "../../fsinfo/fsi_gram.y"
{ yyval.e = new_ether_if(); ;
    break;}
case 16:
#line 193 "../../fsinfo/fsi_gram.y"
{ yyval.e = yyvsp[-3].e; set_ether_if(yyval.e, EF_INADDR, yyvsp[0].s); ;
    break;}
case 17:
#line 195 "../../fsinfo/fsi_gram.y"
{ yyval.e = yyvsp[-3].e; set_ether_if(yyval.e, EF_NETMASK, yyvsp[0].s); ;
    break;}
case 18:
#line 197 "../../fsinfo/fsi_gram.y"
{ yyval.e = yyvsp[-3].e; set_ether_if(yyval.e, EF_HWADDR, yyvsp[0].s); ;
    break;}
case 19:
#line 207 "../../fsinfo/fsi_gram.y"
{ if (yyvsp[0].q) {
		yyval.a = new_auto_tree(yyvsp[-1].s, yyvsp[0].q);
	    } else {
		yyval.a = 0;
	    }
	  ;
    break;}
case 20:
#line 215 "../../fsinfo/fsi_gram.y"
{ yyval.a = 0; ;
    break;}
case 21:
#line 220 "../../fsinfo/fsi_gram.y"
{ yyval.s = strdup(""); ;
    break;}
case 22:
#line 223 "../../fsinfo/fsi_gram.y"
{ yyval.s = yyvsp[0].s; ;
    break;}
case 23:
#line 228 "../../fsinfo/fsi_gram.y"
{ yyval.q = 0; ;
    break;}
case 24:
#line 231 "../../fsinfo/fsi_gram.y"
{ if (yyvsp[0].d) {
		if (yyvsp[-1].q)
			yyval.q = yyvsp[-1].q;
		else
			yyval.q = new_que();
		ins_que(&yyvsp[0].d->d_q, yyval.q->q_back);
	    } else {
		yyval.q = yyvsp[-1].q;
	    }
	  ;
    break;}
case 25:
#line 250 "../../fsinfo/fsi_gram.y"
{ yyvsp[-1].d->d_dev = yyvsp[-3].s; yyval.d = yyvsp[-1].d; ;
    break;}
case 26:
#line 253 "../../fsinfo/fsi_gram.y"
{ yyval.d = (disk_fs *) 0; ;
    break;}
case 27:
#line 269 "../../fsinfo/fsi_gram.y"
{ yyval.d = new_disk_fs(); ;
    break;}
case 28:
#line 272 "../../fsinfo/fsi_gram.y"
{ yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_FSTYPE, yyvsp[0].s); ;
    break;}
case 29:
#line 275 "../../fsinfo/fsi_gram.y"
{ yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_OPTS, yyvsp[0].s); ;
    break;}
case 30:
#line 278 "../../fsinfo/fsi_gram.y"
{ yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_PASSNO, yyvsp[0].s); ;
    break;}
case 31:
#line 281 "../../fsinfo/fsi_gram.y"
{ yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_FREQ, yyvsp[0].s); ;
    break;}
case 32:
#line 284 "../../fsinfo/fsi_gram.y"
{ yyval.d = yyvsp[-2].d; set_disk_fs(yyval.d, DF_MOUNT, (char *) yyvsp[0].q); ;
    break;}
case 33:
#line 287 "../../fsinfo/fsi_gram.y"
{ yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_DUMPSET, yyvsp[0].s); ;
    break;}
case 34:
#line 290 "../../fsinfo/fsi_gram.y"
{ yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_LOG, yyvsp[0].s); ;
    break;}
case 35:
#line 293 "../../fsinfo/fsi_gram.y"
{ yyerror("unknown filesystem attribute"); ;
    break;}
case 36:
#line 307 "../../fsinfo/fsi_gram.y"
{ yyval.q = 0; ;
    break;}
case 37:
#line 310 "../../fsinfo/fsi_gram.y"
{ automount *a = new_automount(yyvsp[-3].s);
	    a->a_volname = yyvsp[0].s;
	    a->a_opts = yyvsp[-2].s;
	    if (yyvsp[-4].q)
		yyval.q = yyvsp[-4].q;
	    else
		yyval.q = new_que();
	    ins_que(&a->a_q, yyval.q->q_back);
	  ;
    break;}
case 38:
#line 320 "../../fsinfo/fsi_gram.y"
{ automount *a = new_automount(yyvsp[-3].s);
            a->a_hardwiredfs = yyvsp[0].s;
            a->a_opts = yyvsp[-2].s;
            if (yyvsp[-4].q)
                yyval.q = yyvsp[-4].q;
            else
                yyval.q = new_que();
            ins_que(&a->a_q, yyval.q->q_back);
          ;
    break;}
case 39:
#line 331 "../../fsinfo/fsi_gram.y"
{ automount *a = new_automount(yyvsp[-2].s);
	    a->a_symlink = yyvsp[0].s;
	    if (yyvsp[-3].q)
		yyval.q = yyvsp[-3].q;
	    else
		yyval.q = new_que();
	    ins_que(&a->a_q, yyval.q->q_back);
	  ;
    break;}
case 40:
#line 341 "../../fsinfo/fsi_gram.y"
{ automount *a = new_automount(yyvsp[-4].s);
	    a->a_mount = yyvsp[-1].q;
	    a->a_opts = yyvsp[-3].s;
	    if (yyvsp[-5].q)
		yyval.q = yyvsp[-5].q;
	    else
		yyval.q = new_que();
	    ins_que(&a->a_q, yyval.q->q_back);
	  ;
    break;}
case 41:
#line 354 "../../fsinfo/fsi_gram.y"
{ yyval.q = 0; ;
    break;}
case 42:
#line 357 "../../fsinfo/fsi_gram.y"
{ yyvsp[-2].m->m_mount = yyvsp[-1].q;
	    yyvsp[-2].m->m_name = yyvsp[-4].s;
	    if (yyvsp[-4].s[0] != '/' && yyvsp[-4].s[1] && strchr(yyvsp[-4].s+1, '/'))
		yyerror("not allowed '/' in a directory name");
	    if (yyvsp[-5].q)
		yyval.q = yyvsp[-5].q;
	    else
		yyval.q = new_que();
	    ins_que(&yyvsp[-2].m->m_q, yyval.q->q_back);
	  ;
    break;}
case 43:
#line 371 "../../fsinfo/fsi_gram.y"
{ yyval.m = new_mount(); ;
    break;}
case 44:
#line 374 "../../fsinfo/fsi_gram.y"
{ yyval.m = yyvsp[-2].m; set_mount(yyval.m, DM_EXPORTFS, yyvsp[0].s); ;
    break;}
case 45:
#line 377 "../../fsinfo/fsi_gram.y"
{ yyval.m = yyvsp[-2].m; set_mount(yyval.m, DM_VOLNAME, yyvsp[0].s); ;
    break;}
case 46:
#line 380 "../../fsinfo/fsi_gram.y"
{ yyval.m = yyvsp[-2].m; set_mount(yyval.m, DM_SEL, yyvsp[0].s); ;
    break;}
case 47:
#line 383 "../../fsinfo/fsi_gram.y"
{ yyerror("unknown directory attribute"); ;
    break;}
case 48:
#line 393 "../../fsinfo/fsi_gram.y"
{ yyval.q = 0; ;
    break;}
case 49:
#line 396 "../../fsinfo/fsi_gram.y"
{ set_fsmount(yyvsp[0].f, FM_VOLNAME, yyvsp[-1].s);
	    if (yyvsp[-3].q)
		yyval.q = yyvsp[-3].q;
	    else
		yyval.q = new_que();
	    ins_que(&yyvsp[0].f->f_q, yyval.q->q_back);
	    ;
    break;}
case 50:
#line 416 "../../fsinfo/fsi_gram.y"
{ yyval.f = new_fsmount(); ;
    break;}
case 51:
#line 419 "../../fsinfo/fsi_gram.y"
{ yyval.f = yyvsp[-1].f; set_fsmount(yyval.f, FM_DIRECT, ""); ;
    break;}
case 52:
#line 422 "../../fsinfo/fsi_gram.y"
{ yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_LOCALNAME, yyvsp[0].s); ;
    break;}
case 53:
#line 425 "../../fsinfo/fsi_gram.y"
{ yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_FROM, yyvsp[0].s); ;
    break;}
case 54:
#line 428 "../../fsinfo/fsi_gram.y"
{ yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_FSTYPE, yyvsp[0].s); ;
    break;}
case 55:
#line 431 "../../fsinfo/fsi_gram.y"
{ yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_OPTS, yyvsp[0].s); ;
    break;}
case 56:
#line 434 "../../fsinfo/fsi_gram.y"
{ yyerror("unknown mount attribute"); ;
    break;}
}
   /* the action file gets copied in in place of this dollarsign */
#line 543 "/usr/share/misc/bison.simple"

  yyvsp -= yylen;
  yyssp -= yylen;
#ifdef YYLSP_NEEDED
  yylsp -= yylen;
#endif

#if YYDEBUG != 0
  if (yydebug)
    {
      short *ssp1 = yyss - 1;
      fprintf (stderr, "state stack now");
      while (ssp1 != yyssp)
	fprintf (stderr, " %d", *++ssp1);
      fprintf (stderr, "\n");
    }
#endif

  *++yyvsp = yyval;

#ifdef YYLSP_NEEDED
  yylsp++;
  if (yylen == 0)
    {
      yylsp->first_line = yylloc.first_line;
      yylsp->first_column = yylloc.first_column;
      yylsp->last_line = (yylsp-1)->last_line;
      yylsp->last_column = (yylsp-1)->last_column;
      yylsp->text = 0;
    }
  else
    {
      yylsp->last_line = (yylsp+yylen-1)->last_line;
      yylsp->last_column = (yylsp+yylen-1)->last_column;
    }
#endif

  /* Now "shift" the result of the reduction.
     Determine what state that goes to,
     based on the state we popped back to
     and the rule number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTBASE] + *yyssp;
  if (yystate >= 0 && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTBASE];

  goto yynewstate;

yyerrlab:   /* here on detecting error */

  if (! yyerrstatus)
    /* If not already recovering from an error, report this error.  */
    {
      ++yynerrs;

#ifdef YYERROR_VERBOSE
      yyn = yypact[yystate];

      if (yyn > YYFLAG && yyn < YYLAST)
	{
	  int size = 0;
	  char *msg;
	  int x, count;

	  count = 0;
	  /* Start X at -yyn if nec to avoid negative indexes in yycheck.  */
	  for (x = (yyn < 0 ? -yyn : 0);
	       x < (sizeof(yytname) / sizeof(char *)); x++)
	    if (yycheck[x + yyn] == x)
	      size += strlen(yytname[x]) + 15, count++;
	  msg = (char *) malloc(size + 15);
	  if (msg != 0)
	    {
	      strcpy(msg, "parse error");

	      if (count < 5)
		{
		  count = 0;
		  for (x = (yyn < 0 ? -yyn : 0);
		       x < (sizeof(yytname) / sizeof(char *)); x++)
		    if (yycheck[x + yyn] == x)
		      {
			strcat(msg, count == 0 ? ", expecting `" : " or `");
			strcat(msg, yytname[x]);
			strcat(msg, "'");
			count++;
		      }
		}
	      yyerror(msg);
	      free(msg);
	    }
	  else
	    yyerror ("parse error; also virtual memory exceeded");
	}
      else
#endif /* YYERROR_VERBOSE */
	yyerror("parse error");
    }

  goto yyerrlab1;
yyerrlab1:   /* here on error raised explicitly by an action */

  if (yyerrstatus == 3)
    {
      /* if just tried and failed to reuse lookahead token after an error, discard it.  */

      /* return failure if at end of input */
      if (yychar == YYEOF)
	YYABORT;

#if YYDEBUG != 0
      if (yydebug)
	fprintf(stderr, "Discarding token %d (%s).\n", yychar, yytname[yychar1]);
#endif

      yychar = YYEMPTY;
    }

  /* Else will try to reuse lookahead token
     after shifting the error token.  */

  yyerrstatus = 3;		/* Each real token shifted decrements this */

  goto yyerrhandle;

yyerrdefault:  /* current state does not do anything special for the error token. */

#if 0
  /* This is wrong; only states that explicitly want error tokens
     should shift them.  */
  yyn = yydefact[yystate];  /* If its default is to accept any token, ok.  Otherwise pop it.*/
  if (yyn) goto yydefault;
#endif

yyerrpop:   /* pop the current state because it cannot handle the error token */

  if (yyssp == yyss) YYABORT;
  yyvsp--;
  yystate = *--yyssp;
#ifdef YYLSP_NEEDED
  yylsp--;
#endif

#if YYDEBUG != 0
  if (yydebug)
    {
      short *ssp1 = yyss - 1;
      fprintf (stderr, "Error: state stack now");
      while (ssp1 != yyssp)
	fprintf (stderr, " %d", *++ssp1);
      fprintf (stderr, "\n");
    }
#endif

yyerrhandle:

  yyn = yypact[yystate];
  if (yyn == YYFLAG)
    goto yyerrdefault;

  yyn += YYTERROR;
  if (yyn < 0 || yyn > YYLAST || yycheck[yyn] != YYTERROR)
    goto yyerrdefault;

  yyn = yytable[yyn];
  if (yyn < 0)
    {
      if (yyn == YYFLAG)
	goto yyerrpop;
      yyn = -yyn;
      goto yyreduce;
    }
  else if (yyn == 0)
    goto yyerrpop;

  if (yyn == YYFINAL)
    YYACCEPT;

#if YYDEBUG != 0
  if (yydebug)
    fprintf(stderr, "Shifting error token, ");
#endif

  *++yyvsp = yylval;
#ifdef YYLSP_NEEDED
  *++yylsp = yylloc;
#endif

  yystate = yyn;
  goto yynewstate;

 yyacceptlab:
  /* YYACCEPT comes here.  */
  if (yyfree_stacks)
    {
      free (yyss);
      free (yyvs);
#ifdef YYLSP_NEEDED
      free (yyls);
#endif
    }
  return 0;

 yyabortlab:
  /* YYABORT comes here.  */
  if (yyfree_stacks)
    {
      free (yyss);
      free (yyvs);
#ifdef YYLSP_NEEDED
      free (yyls);
#endif
    }
  return 1;
}
#line 436 "../../fsinfo/fsi_gram.y"
